# Documentation

## Requirements

- install packages

```
pip install pymdown-extensions pygments mkdocs-material
```

- Add extensions in **mkdocs.yaml**

```
markdown_extensions:
  - admonition
  - pymdownx.arithmatex
  - pymdownx.details
  - codehilite
  - pymdownx.superfences
```

## More

[for more information](https://pjjk.net/mdmkdocs/extensions/)
